#!/usr/bin/env python

#  convo.py
#  conversation table for recent connections, current connections
#  
#  Elliot Pennington 2008

class Conversation:
    
    def __init__(self, client, befriender):
        """
        Start a conversation between a client and a befriender.
        """
        self.client = client
        self.befriender = befriender
        self.file = None
        self.recent = False

    def setActive(self):
        self.recent = False

    def setRecent(self):
        self.recent = True

class Conversations:
    
    """
    Threadsafe collection of conversations. Works similarly to Befrienders.
    
    Attributes:
        array_lock: This a semaphore for locking the internal list on access. 
        __index: the iteration state of the array.
        __array: the internal array to store the Conversation objects.
    """
    
    def __init__(self):
        self.array_lock = threading.RLock()
        self.__index = 0
        self.__array = []
    
    def add_conversation(self, conversation):
        self.array_lock.acquire()
        try:
            self.__array.append(befriender)
        finally:
            self.array_lock.release()
    
    def client_in_convo(self, client):
        """
        Return true if the specified client screen name is in a conversation.
        Return false otherwise.
        
        Args:
            client: the screenname (scrambled) of the client in question
        
        TODO: maybe make everything accept serial numbers?
        """
        self.array_lock.acquire()
        for convo in self.__array:
            if convo.client == client:
                self.array_lock.release()
                return True
        self.array_lock.release()
        return False
    
    def remove_convo_with_client(self, client):
        self.array_lock.acquire()
        for convo in self.__array:
            if convo.client == client:
                self.__array.remove(convo)
        self.array_lock.release()

    
    def remove_convo_with_befriender(self, befriender):
        self.array_lock.acquire()
        for convo in self.__array:
            if convo.befriender == befriender:
                self.__array.remove(convo)
        self.array_lock.release()
    
